@@ -14,10 +14,7 @@ class NeverGradAlgoWrapper():
 
     def create(self, metric, mode, search_space, **args):
         search_space = NeverGradSpace(search_space).get_search_space()
-        if ('method' in args) and (args['method']):
-            method = args['method']
-        else:
-            method = self.default_method
+        method = args.pop('method', self.default_method)
         optimizer = ng.optimizers.registry[method](
                 parametrization=search_space, budget=self.default_budget)
         self.algorithm = NevergradSearch(optimizer, None, metric=metric, mode=mode, **args)
