@@ -129,7 +129,7 @@ class PandaTaskManager():
                 help='only show the task with the specified jeditaskid')
             parser.add_argument('-m', '--metadata', action='store_true',
                 help='print out the metadata of a task')
-            parser.add_argument('-s', '--status', 
+            parser.add_argument('-s', '--status', nargs='+',
                 help='filter tasks by task status')
             parser.add_argument('-y', '--sync', action='store_true',
                 help='force no caching on the PanDA server')
@@ -221,7 +221,7 @@ class PandaTaskManager():
 
         print('INFO: Showing only max {} tasks in last {} days.'
             ' One can set "--days N" to see tasks in last N days,'
-            ' and "--limit M" to see at most M latest tasks'
+            ' \n      and "--limit M" to see at most M latest tasks'
             .format(limit, days))
         response = None
         req = self.get_request(kPanDA_TaskURL, params)
@@ -328,7 +328,8 @@ class PandaTaskManager():
         outcol = params.pop('outcol', None)
         print('INFO: Fetching PanDA Tasks...')
         datasets = self.query_tasks(**params)
-
+        
+        print('')
         if args.metadata:
             self.print_metadata(datasets)
         else:
